/*
 Copyright (C) 2015 SAS Institute Inc. Cary, NC, USA
*/

/**
   \file
   
   \brief   Binary append the content of a file to another.
   
   \param [in] file fileref or full file path of the file to be appended
   \param [in] toFile fileref or full file path of the target file
      
   \details 
   This macro performs a binary copy of the source file (<i><b>&file</b></i>) to the target file (<i><b>&toFile</b></i>)
         
   \ingroup macroUtils
   
   \author  SAS Institute Inc.
   \date    2015
*/
%macro irm_file_append(file =,  toFile =);
   
   %local
      fref1
      fref2
      clear_toFile
      clear_file
   ;
   
   %let fref1 = &toFile.;
   %let clear_toFile = N;
   %if(%length(&toFile.) > 8) %then %do;
      /* &toFile is definitely a path to a file name */
      filename f1 "&toFile.";
      %let clear_toFile = Y;
      %let fref1 = f1;
   %end;
   %else %do;
      %if(%sysfunc(fileref(&toFile.)) > 0) %then %do;
         /* It is not a fileref. Although short, it must be a file path */
         filename f1 "&toFile.";
         %let clear_toFile = Y;
         %let fref1 = f1;
      %end;
   %end;

   
   %let fref2 = &file.;
   %let clear_file = N;
   %if(%length(&file.) > 8) %then %do;
      /* &file is definitely a path to a file name */
      filename f2 "&file.";
      %let clear_file = Y;
      %let fref2 = f2;
   %end;
   %else %do;
      %if(%sysfunc(fileref(&toFile.)) > 0) %then %do;
         /* It is not a fileref. Although short, it must be a file path */
         filename f2 "&file.";
         %let clear_file = Y;
         %let fref2 = f2;
      %end;
   %end;
   
   
    /* copy the file byte-for-byte  */
    data _null_;
        length fileID1 8 fileID2 8;
        fileID1 = fopen("&fref1.", 'A', 1, 'B');
        fileID2 = fopen("&fref2.", 'I', 1, 'B');
        rec = '20'x;

        do while(fread(fileID2) = 0);
            rc = fget(fileID2, rec, 1);
            rc = fput(fileID1, rec);
            rc = fwrite(fileID1);
        end;

        rc = fclose(fileID1);
        rc = fclose(fileID2);
    run;

   %if(&clear_toFile. = Y) %then %do;
      filename f1 clear;
   %end;
   
   %if(&clear_file. = Y) %then %do;
      filename f2 clear;
   %end;
   
%mend irm_file_append;
