/*
 Copyright (C) 2015 SAS Institute Inc. Cary, NC, USA
*/

/**
   \file
   
   \brief   This macro initializes the IRM environment
   
   \ingroup development

   \param [in] env_path Path to the root folder of the data environment - this would be the folder that contains the landing_area
   \param [in] source_path Path to the root folder of the Federated Content Area (root folder, excluding the Federated Content folder)
   \param [in] fa_id Name of the Federated Content folder

   \author  SAS Institute Inc.
   \date    2017
*/


%macro irm_setup(  env_path =
                 , source_path = 
                 , fa_id =
                 , config_set_id =
                 , base_dt =
                 );
   %local
      libpath
   ;
   
   /* ***************************************************************************/
   /* When env_path and source_path are equal or the fa_id is contained already */
   /* in the source_path, strip the federated area                              */ 
   /* name from the source_path                                                 */
   /* ***************************************************************************/

   %if %index(%bquote(&source_path), &fa_id) %then %do;
      data _null_;
         call symput("source_path", substr("&source_path.", 1, findc("&source_path", "/\", -length("&source_path"))-1));
      run;
      %put NOTE: source_path reset to &source_path;
   %end;
   
   /* If missing, set the value of env_path to the location of the federated area */
   %if (%length(&env_path.) = 0) %then
      %let env_path = &source_path./&fa_id.;
   
   /* ***************************************************************************/
   /* Update sasautos and setup LUA paths                                       */
   /* ***************************************************************************/
   %if(%length(&source_path.)) %then %do;
      /* Add macros to the auto search path */
      options insert = (sasautos = ("&source_path./&fa_id./source/sas/ucmacros"));
      
      /*setup Lua path*/
      filename RISKEXEC ( "&source_path./&fa_id./source/lua" );
      filename LUAPATH ( "&source_path./&fa_id./source/lua" );
   %end;

%mend;
